@@ -256,11 +256,14 @@ gnome_print_copies_selector_init (GnomePrintCopiesSelector *gpc)
 	AtkRelation *relation;
 	AtkObject *relation_targets[1];
 	AtkObject *atko;
+	gchar *text;
 
 	frame = gtk_frame_new ("");
 	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_NONE);
 	label = gtk_label_new ("");
-	gtk_label_set_markup (GTK_LABEL (label), _("<b>Copies</b>"));
+	text = g_strdup_printf ("<b>%s</b>", _("Copies"));
+	gtk_label_set_markup (GTK_LABEL (label), text);
+	g_free (text);
 	gtk_frame_set_label_widget (GTK_FRAME (frame), label);
 	gtk_widget_show (label);
 	gtk_container_add (GTK_CONTAINER (gpc), frame);
