@@ -20,8 +20,10 @@
  *    Michael Zucchi <notzed@helixcode.com>
  *    Chema Celorio <chema@celorio.com>
  *    Lauris Kaplinski <lauris@ximian.com>
+ *    Andreas J. Guelzow <aguelzow@taliesin.ca>
  *
  *  Copyright (C) 2000-2002 Ximian Inc.
+ *  Copyright (C) 2004 Andreas J. Guelzow
  *
  */
 
@@ -141,6 +143,21 @@ gnome_print_dialog_init (GnomePrintDialog *gpd)
 	/* Empty */
 }
 
+void 
+gnome_print_dialog_response_cb (GtkDialog *dialog,
+				gint response_id,
+				GnomePrintDialog *gpd)
+{
+	if (response_id != GNOME_PRINT_DIALOG_RESPONSE_PRINT)
+		return;
+
+	if (!gnome_printer_selector_check_consistency  
+	    (GNOME_PRINTER_SELECTOR (gpd->printer)))
+		g_signal_stop_emission_by_name (dialog, "response");
+}
+
+
+
 static void
 gpd_copies_set (GnomePrintCopiesSelector *gpc, 
 		gint copies,
@@ -167,6 +184,7 @@ static GtkWidget *
 gpd_create_job_page (GnomePrintDialog *gpd)
 {
 	GtkWidget *hb, *vb, *f, *c, *l;
+	gchar *text;
 
 	hb = gtk_hbox_new (FALSE, 0);
 
@@ -178,7 +196,9 @@ gpd_create_job_page (GnomePrintDialog *gpd)
 	f = gtk_frame_new ("");
 	gtk_frame_set_shadow_type (GTK_FRAME (f), GTK_SHADOW_NONE);
 	l = gtk_label_new ("");
-	gtk_label_set_markup (GTK_LABEL (l), _("<b>Print range</b>"));
+	text = g_strdup_printf ("<b>%s</b>", _("Print Range"));
+	gtk_label_set_markup (GTK_LABEL (l), text);
+	g_free (text);
 	gtk_frame_set_label_widget (GTK_FRAME (f), l);
 	gtk_widget_show (l);
 	gtk_widget_hide (f);
@@ -393,6 +413,11 @@ gnome_print_dialog_construct (GnomePrintDialog *gpd, const guchar *title, gint f
 	gtk_dialog_set_default_response (GTK_DIALOG (gpd),
 					 GNOME_PRINT_DIALOG_RESPONSE_PRINT);
 
+	g_signal_connect (gpd, "response",
+			  G_CALLBACK (gnome_print_dialog_response_cb),
+			  (gpointer) gpd);
+
+
 	/* Construct job options, if needed */
 	if (flags & GNOME_PRINT_DIALOG_RANGE) {
 		GtkWidget *r;
@@ -739,21 +764,22 @@ gnome_print_dialog_get_config (GnomePrintDialog *gpd)
 
 /**
  * gnome_print_dialog_run:
- * @dialog: 
+ * @gpd: 
  * 
  * Runs a gnome-print dialog. Use it instead of gtk_dialog_run
  * in the future this function will handle more stuff like opening
  * a file selector when printing to a file.
+ *
+ * Note: this routine does not destroy the dialog!
  * 
  * Return Value: the user response
  **/
 gint
-gnome_print_dialog_run (GnomePrintDialog *dialog)
+gnome_print_dialog_run (GnomePrintDialog const *gpd)
 {
 	gint response;
 
-	response = gtk_dialog_run (GTK_DIALOG (dialog));
-	gtk_widget_destroy (GTK_WIDGET (dialog));
+	response = gtk_dialog_run (GTK_DIALOG (gpd));
 
 	return response;
 }
