@@ -33,6 +33,7 @@
 
 #include "gnome-print-i18n.h"
 #include "gnome-printer-selector.h"
+#include "gnome-print-config-dialog.h"
 #include <libgnomeprint/gnome-print-config.h>
 
 #include "gpaui/gpa-printer-selector.h"
@@ -115,17 +116,26 @@ static gint
 gnome_printer_selector_construct (GPAWidget *gpa_widget)
 {
 	GnomePrinterSelector *gpw;
-	GtkWidget *f, *t, *b, *l, *h, *v;
+	GtkWidget *f, *t, *b, *l, *h, *v, *label;
 	AtkRelationSet *relation_set;
 	AtkRelation *relation;
 	AtkObject *relation_targets[2];
 	AtkObject *atko, *label_atko, *menu_atko, *button_atko;
+	gchar *text;
 
 	gpw = GNOME_PRINTER_SELECTOR (gpa_widget);
 
 	gpw->accel_group = gtk_accel_group_new ();
 
-	f = gtk_frame_new (_("Printer"));
+	f = gtk_frame_new ("");
+	gtk_frame_set_shadow_type (GTK_FRAME (f), GTK_SHADOW_NONE);
+	label = gtk_label_new ("");
+	text = g_strdup_printf ("<b>%s</b>", _("Printer"));
+	gtk_label_set_markup (GTK_LABEL (label), text);
+	g_free (text);
+	gtk_frame_set_label_widget (GTK_FRAME (f), label);
+	gtk_widget_show (label);
+
 	v = gtk_vbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (v), f, 0, 0, 0);
 	gtk_container_add (GTK_CONTAINER (gpw), v);
@@ -176,12 +186,9 @@ gnome_printer_selector_construct (GPAWidget *gpa_widget)
 	atko = gtk_widget_get_accessible (b);
 	atk_object_set_description (atko, _("Adjust the settings of the selected printer"));
 
-	/* FIXME: remove the following line when gpw_configure_clicked will be implemented */
-	gtk_widget_set_sensitive (b, FALSE);
-
 	gpw->printers = gpa_widget_new (GPA_TYPE_PRINTER_SELECTOR, NULL);
 	gtk_widget_show (gpw->printers);
-	gtk_table_attach (GTK_TABLE (t), gpw->printers, 1, 2, 0, 1,
+	gtk_table_attach (GTK_TABLE (t), gpw->printers, 1, 3, 0, 1,
 			  GTK_FILL, 0,
 			  GPS_PAD, GPS_PAD);
 	gpw_create_label_with_mnemonic (GTK_TABLE (t), 0, 1, 0, 1,
@@ -383,4 +390,28 @@ gpw_create_label_with_mnemonic (GtkTable *table, gint l, gint r, gint t, gint b,
 static void
 gpw_configure_clicked (GtkWidget *widget, GPAWidget *gpaw)
 {
+	GnomePrinterSelector *gpw = GNOME_PRINTER_SELECTOR (gpaw);
+	GnomePrintConfig *gp_conf = gnome_printer_selector_get_config (gpw);
+	GtkWidget * gpcd = gnome_print_config_dialog_new (gp_conf);
+
+	gnome_print_config_unref (gp_conf);
+
+	while (gtk_widget_get_parent (widget))
+		widget = gtk_widget_get_parent (widget);
+
+	gtk_window_set_transient_for (GTK_WINDOW(gpcd), GTK_WINDOW(widget));
+
+	gtk_widget_show (gpcd);
+
+	gtk_dialog_run (GTK_DIALOG (gpcd));
+	
+	gtk_widget_destroy (GTK_WIDGET (gpcd));
+}
+
+
+gboolean           
+gnome_printer_selector_check_consistency (GnomePrinterSelector *psel)
+{
+	return gpa_transport_selector_check_consistency 
+		(GPA_TRANSPORT_SELECTOR (psel->transport));
 }
